=======================
Wildbook IA - PyDarknet
=======================

|Build| |Pypi| |ReadTheDocs|

Python wrapper for Darknet - Part of the WildMe / Wildbook IA Project.

Unix / Mac compatible distribution based on the code developed by Redmon et. al.

Repos relevant to the ibeis project:

* https://github.com/WildMeOrg/wildbook-ia

* https://github.com/bluemellophone/IBEIS2014


.. |Build| image:: https://img.shields.io/github/workflow/status/WildMeOrg/wbia-tpl-pydarknet/Build%20and%20upload%20to%20PyPI/main
    :target: https://github.com/WildMeOrg/wbia-tpl-pydarknet/actions?query=branch%3Amain+workflow%3A%22Build+and+upload+to+PyPI%22
    :alt: Build and upload to PyPI (main)

.. |Pypi| image:: https://img.shields.io/pypi/v/wbia-pydarknet.svg
   :target: https://pypi.python.org/pypi/wbia-pydarknet
   :alt: Latest PyPI version

.. |ReadTheDocs| image:: https://readthedocs.org/projects/wbia-tpl-pydarknet/badge/?version=latest
    :target: http://wbia-tpl-pydarknet.readthedocs.io/en/latest/
    :alt: Documentation on ReadTheDocs
